@@ -6,12 +6,10 @@ from urllib import parse
 
 from .. import BaseService
 
-from .client import ExtraHopClient
+from .client import Client
 
 
 class Service(BaseService):
-    _conn_params = {}
-
     application = None
 
     def __init__(self, scheme, conn_str):
@@ -53,4 +51,4 @@ class Service(BaseService):
         if not verify:
             urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
-        return ExtraHopClient(**self._conn_params, verify=verify)
+        return Client(verify=verify, **self._conn_params)
